@@ -75,6 +75,7 @@ static void zoom_100_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer);
 static void open_in_browser_cb(GtkWidget *widget, FancyViewer *viewer);
 static WebKitNavigationResponse fancy_open_uri (FancyViewer *viewer, gboolean external);
 static void fancy_create_popup_prefs_menu(FancyViewer *viewer);
+static void fancy_show_notice(FancyViewer *viewer, const gchar *message);
 #ifdef HAVE_LIBCURL
 static size_t download_file_curl_write_cb(void *buffer, size_t size, 
 										  size_t nmemb, void *data);
@@ -94,7 +95,7 @@ static GtkWidget *fancy_get_widget(MimeViewer *_viewer)
 	return GTK_WIDGET(viewer->vbox);
 }
 
-static gint fancy_show_mimepart_real(MimeViewer *_viewer)
+static gboolean fancy_show_mimepart_real(MimeViewer *_viewer)
 {
 	FancyViewer *viewer = (FancyViewer *) _viewer;
 	MessageView *messageview = ((MimeViewer *)viewer)->mimeview 
@@ -144,7 +145,10 @@ static gint fancy_show_mimepart_real(MimeViewer *_viewer)
 	viewer->loading = FALSE;
 	return FALSE;
 }
-
+static void fancy_show_notice(FancyViewer *viewer, const gchar *message)
+{
+	gtk_label_set_text(GTK_LABEL(viewer->l_link), message);
+}
 static gint fancy_show_mimepart_prepare(MimeViewer *_viewer)
 {
 	FancyViewer *viewer = (FancyViewer *) _viewer;
@@ -157,7 +161,7 @@ static gint fancy_show_mimepart_prepare(MimeViewer *_viewer)
 		}
 	}
     
-	viewer->tag = g_timeout_add(5, (GtkFunction)fancy_show_mimepart_real, viewer);
+	viewer->tag = g_timeout_add(5, (GSourceFunc)fancy_show_mimepart_real, viewer);
 	return FALSE;
 }
 
@@ -307,6 +311,7 @@ static void fancy_clear_viewer(MimeViewer *_viewer)
 	viewer->override_prefs_images = FALSE;
 	viewer->override_prefs_scripts = FALSE;
 	viewer->override_prefs_plugins = FALSE;
+	viewer->override_prefs_java = FALSE;
 	webkit_web_view_open(viewer->view, "about:blank");
 	debug_print("fancy_clear_viewer\n");
 	fancy_prefs.zoom_level = webkit_web_view_get_zoom_level(viewer->view) * 100;
@@ -377,10 +382,21 @@ navigation_requested_cb(WebKitWebView *view, WebKitWebFrame *frame,
 		g_object_set(viewer->settings, "enable-plugins", TRUE, NULL);
 		webkit_web_view_set_settings(viewer->view, viewer->settings);
 	}
-
+	if (!fancy_prefs.enable_java && !viewer->override_prefs_java) {
+		g_object_set(viewer->settings, "enable-java-applet", FALSE, NULL);
+		webkit_web_view_set_settings(viewer->view, viewer->settings);
+	}
+	else {
+		g_object_set(viewer->settings, "enable-java-applet", TRUE, NULL);
+		webkit_web_view_set_settings(viewer->view, viewer->settings);
+	}
 	if (fancy_prefs.block_extern_content && !viewer->override_prefs_block_extern_content) {
-		if (viewer->load_page)
+		if (viewer->load_page) {
+			gchar *message = g_strconcat(_("Navigation to "), viewer->cur_link, _(" blocked"), NULL);
+			fancy_show_notice(viewer, message);
+			g_free(message);
 			return WEBKIT_NAVIGATION_RESPONSE_IGNORE; 
+		}
 	} 
 
 	if (viewer->cur_link) {
@@ -459,6 +475,12 @@ static void fancy_enable_plugins_activated(GtkMenuItem *item, FancyViewer *viewe
 	gtk_widget_set_sensitive(GTK_WIDGET(item), FALSE);
 	webkit_web_view_reload (viewer->view);
 }
+static void fancy_enable_java_activated(GtkMenuItem *item, FancyViewer *viewer) {
+	viewer->load_page = FALSE;
+	viewer->override_prefs_java = TRUE;
+	gtk_widget_set_sensitive(GTK_WIDGET(item), FALSE);
+	webkit_web_view_reload (viewer->view);
+}
 static void fancy_open_external_activated(GtkMenuItem *item, FancyViewer *viewer) {
 	viewer->override_prefs_external = TRUE;
 	gtk_widget_set_sensitive(GTK_WIDGET(item), FALSE);
@@ -493,6 +515,14 @@ static gboolean fancy_prefs_cb(GtkWidget *widget, GdkEventButton *ev, FancyViewe
 			else
 				gtk_widget_set_sensitive(viewer->enable_plugins, TRUE);
 		}
+		if (fancy_prefs.enable_java)
+			gtk_widget_set_sensitive(viewer->enable_java, FALSE);
+		else {
+			if (viewer->override_prefs_java) 
+				gtk_widget_set_sensitive(viewer->enable_java, FALSE);
+			else
+				gtk_widget_set_sensitive(viewer->enable_java, TRUE);
+		}
 		if (!fancy_prefs.block_extern_content)
 			gtk_widget_set_sensitive(viewer->block_extern_content, FALSE);
 		else {
@@ -519,10 +549,11 @@ static gboolean fancy_prefs_cb(GtkWidget *widget, GdkEventButton *ev, FancyViewe
 
 static void fancy_create_popup_prefs_menu(FancyViewer *viewer) {
 	GtkWidget *auto_load_images;
-	GtkWidget *item_image, *item_image2, *item_image3, *item_image4, *item_image5;
+	GtkWidget *item_image;
 	GtkWidget *block_extern_content;
 	GtkWidget *enable_scripts;
 	GtkWidget *enable_plugins;
+	GtkWidget *enable_java;
 	GtkWidget *open_external;
 
 	auto_load_images = gtk_image_menu_item_new_with_label(_("Load images"));
@@ -530,18 +561,22 @@ static void fancy_create_popup_prefs_menu(FancyViewer *viewer) {
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(auto_load_images), item_image);
 
 	block_extern_content = gtk_image_menu_item_new_with_label(_("Unblock external content"));
-	item_image2 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(block_extern_content), item_image2);
+	item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(block_extern_content), item_image);
 
 	enable_scripts = gtk_image_menu_item_new_with_label(_("Enable Javascript"));
-	item_image3 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_scripts), item_image3);
+	item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_scripts), item_image);
+	item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
 	enable_plugins = gtk_image_menu_item_new_with_label(_("Enable Plugins"));
-	item_image4 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_plugins), item_image4);
+	item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_plugins), item_image);
+	enable_java = gtk_image_menu_item_new_with_label(_("Enable Java"));
+	item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(enable_java), item_image);
 	open_external = gtk_image_menu_item_new_with_label(_("Open links with external browser"));
-	item_image5 = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(open_external), item_image5);
+	item_image = gtk_image_new_from_stock(GTK_STOCK_EXECUTE, GTK_ICON_SIZE_MENU);
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(open_external), item_image);
 
 	g_signal_connect(G_OBJECT(auto_load_images), "activate",
 					 G_CALLBACK (fancy_auto_load_images_activated), viewer);
@@ -551,6 +586,8 @@ static void fancy_create_popup_prefs_menu(FancyViewer *viewer) {
 					 G_CALLBACK (fancy_enable_scripts_activated), viewer);
 	g_signal_connect(G_OBJECT(enable_plugins), "activate",
 					 G_CALLBACK (fancy_enable_plugins_activated), viewer);
+	g_signal_connect(G_OBJECT(enable_java), "activate",
+					 G_CALLBACK (fancy_enable_java_activated), viewer);
 	g_signal_connect(G_OBJECT(open_external), "activate",
 					 G_CALLBACK (fancy_open_external_activated), viewer);
 
@@ -558,6 +595,7 @@ static void fancy_create_popup_prefs_menu(FancyViewer *viewer) {
 	gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), block_extern_content);
 	gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), enable_scripts);
 	gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), enable_plugins);
+	gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), enable_java);
 	gtk_menu_shell_append(GTK_MENU_SHELL(viewer->fancy_prefs_menu), open_external);
 
 	gtk_menu_attach_to_widget(GTK_MENU(viewer->fancy_prefs_menu), viewer->ev_fancy_prefs, NULL);
@@ -566,6 +604,7 @@ static void fancy_create_popup_prefs_menu(FancyViewer *viewer) {
 	viewer->auto_load_images = auto_load_images;
 	viewer->enable_scripts = enable_scripts;
 	viewer->enable_plugins = enable_plugins;
+	viewer->enable_java = enable_java;
 	viewer->block_extern_content = block_extern_content;
 	viewer->open_external = open_external;
 
@@ -928,7 +967,6 @@ static void zoom_out_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 static MimeViewer *fancy_viewer_create(void)
 {
 	FancyViewer    *viewer;
-	GtkAdjustment  *adj;
 	GtkWidget      *hbox;
     
 	debug_print("fancy_viewer_create\n");
@@ -949,11 +987,18 @@ static MimeViewer *fancy_viewer_create(void)
 	viewer->view = WEBKIT_WEB_VIEW(webkit_web_view_new());
 
 #ifdef HAVE_LIBSOUP_GNOME    
-	SoupSession *session;
-	session = webkit_get_default_session();
  /* Use GNOME proxy settings through libproxy */
-	soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);    
+	if (fancy_prefs.enable_gnome_proxy) {
+		SoupSession *session = webkit_get_default_session();
+		soup_session_add_feature_by_type (session, SOUP_TYPE_PROXY_RESOLVER_GNOME);
+	}
 #endif
+	
+	if (fancy_prefs.enable_proxy) {
+		SoupSession *session = webkit_get_default_session();
+		SoupURI* pURI = soup_uri_new(fancy_prefs.proxy_str);
+		g_object_set(session, "proxy-uri", pURI, NULL);
+	}
     
 	viewer->settings = webkit_web_settings_new();    
 	viewer->scrollwin = gtk_scrolled_window_new(NULL, NULL);
@@ -965,7 +1010,6 @@ static MimeViewer *fancy_viewer_create(void)
 	gtk_container_add(GTK_CONTAINER(viewer->scrollwin),
 					  GTK_WIDGET(viewer->view));
 
-	adj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(viewer->scrollwin));
 	viewer->vbox = gtk_vbox_new(FALSE, 0);
 	hbox = gtk_hbox_new(FALSE, 0);
 	viewer->progress = gtk_progress_bar_new();
