@@ -495,6 +495,12 @@ gint plugin_init(gchar **error)
 			   VERSION_NUMERIC, _("GeoLocation"), error))
     return -1;
 
+  if(gtk_clutter_init(0, NULL) != CLUTTER_INIT_SUCCESS)
+  {
+    *error = g_strdup_printf(_("Could not initialize clutter"));
+    return -1;
+  }
+
   ip_from_received_header_regex = g_regex_new(EXTRACT_IP_FROM_RECEIVED_HEADER_REGEX, 0, 0, &err);
   if(err) {
     *error = g_strdup_printf(_("Could not create regular expression: %s\n"), err->message);
@@ -513,11 +519,11 @@ gint plugin_init(gchar **error)
   hook_messageview_show = hooks_register_hook(MESSAGE_VIEW_SHOW_DONE_HOOKLIST, my_messageview_show_hook, NULL);
   if(hook_messageview_show == (guint) -1) {
     *error = g_strdup(_("Failed to register messageview_show hook in the GeoLocation plugin"));
+    g_regex_unref(ip_from_received_header_regex);
+    g_regex_unref(lat_lon_from_hostip_response_regex);
     return -1;
   }
 
-  gtk_clutter_init(0, NULL);
-
   debug_print("GeoLocation plugin loaded\n");
 
   return 0;
