@@ -200,24 +200,6 @@ static gboolean load_images(GtkHtml2Viewer *viewer)
 	return FALSE;
 }
 
-static gboolean has_charset(FILE *fp)
-{
-	gchar buf[4096];
-	gint loaded = 0;
-
-	memset(buf, 0, sizeof(buf));
-	while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
-		if (strcasestr(buf, "<meta") &&
-		    strcasestr(buf, "http-equiv") &&
-		    strcasestr(buf, "charset")) {
-			rewind(fp);
-			return TRUE;
-		}
-	}
-	rewind(fp);
-	return FALSE;
-}
-
 static gboolean has_header(FILE *fp)
 {
 	gchar buf[4096];
@@ -249,12 +231,22 @@ static void gtkhtml2_restore_focus(void)
 		summary_grab_focus(mainwin->summaryview);
 }
 
-static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
+static void insert_charset_header(HtmlDocument *html_doc, const char *charset)
+{
+	gchar *header = g_strdup_printf(
+		"<html><head>"
+		"<meta http-equiv=\"Content-Type\""
+		 "content=\"text/html; charset=%s\">"
+		"</head>", charset);
+	html_document_write_stream(html_doc, header, strlen(header));
+	g_free(header);
+}
+
+static gboolean gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 {
 	GtkHtml2Viewer *viewer = (GtkHtml2Viewer *) _viewer;
 	FILE *fp;
 	gchar buf[4096];
-	gint loaded = 0;
 	const gchar *charset = NULL;
 	MessageView *messageview = ((MimeViewer *)viewer)->mimeview 
 					? ((MimeViewer *)viewer)->mimeview->messageview 
@@ -288,8 +280,6 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 
 	html_view_zoom_reset(HTML_VIEW(viewer->html_view));
 	if (partinfo && !(procmime_get_part(viewer->filename, partinfo) < 0)) {
-		gboolean insert_in_header = FALSE, insert_all_header = FALSE;
-
 		if (_viewer && _viewer->mimeview &&
 		    _viewer->mimeview->messageview->forced_charset)
 			charset = _viewer->mimeview->messageview->forced_charset;
@@ -298,10 +288,10 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 		if (charset == NULL)
 			charset = conv_get_locale_charset_str();
 
-		debug_print("using charset %s by default\n", charset);
+		debug_print("using charset %s\n", charset);
 		
 		if (html_document_open_stream(viewer->html_doc, "text/html")) {
-			gboolean got_charset = FALSE;
+			gboolean skip_header;
 			fp = g_fopen(viewer->filename, "rb");
 
 			if (fp == NULL) {
@@ -309,57 +299,30 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 				goto out;
 			}
 
-			got_charset = has_charset(fp);
-			if (!got_charset) {
-				if (has_header(fp))
-					insert_in_header = TRUE;
-				else
-					insert_all_header = TRUE;
-			}
+			skip_header = has_header(fp);
+			if (!skip_header)
+				insert_charset_header(viewer->html_doc, charset);
 
-			while ((loaded = fread(buf, 1, 4096, fp)) > 0) {
+			while (fgets(buf, sizeof(buf), fp) != NULL) {
 				g_mutex_lock(viewer->mutex);
-				if (!viewer->stop_previous && !claws_is_exiting() && got_charset == FALSE) {
-					if (insert_all_header) {
-						gchar *meta_charset = g_strdup_printf(
-							"<head><meta http-equiv=Content-Type content=\"text/html; charset=%s\"></head>",
-							charset);
-						html_document_write_stream(
-							viewer->html_doc, meta_charset, strlen(meta_charset));
-						debug_print("injected %s\n", meta_charset);
-						g_free(meta_charset);
-						got_charset = TRUE;
-					} else if (insert_in_header && strcasestr(buf, "</head>")) {
-						gchar *tmp_buf = g_malloc(loaded+1);
-						gchar *start = NULL, *end = NULL;
-						gchar *meta_charset = g_strdup_printf(
-							"<meta http-equiv=Content-Type content=\"text/html; charset=%s\">",
-							charset);
 
-						strncpy(tmp_buf, buf, loaded);
-						tmp_buf[loaded] = '\0';
-
-						start = g_strdup(tmp_buf);
-						*(strcasestr(start, "</head>")) = '\0';
-						end = g_strdup(strcasestr(tmp_buf, "</head>"));
-						
-						html_document_write_stream(
-							viewer->html_doc, start, strlen(start));
-						html_document_write_stream(
-							viewer->html_doc, meta_charset, strlen(meta_charset));
-						strncpy(buf, end, strlen(end));
-						loaded = strlen(end);
-						debug_print("injected %s in head\n", meta_charset);
-						g_free(tmp_buf);
-						g_free(meta_charset);
-						g_free(start);
-						g_free(end);
-						got_charset = TRUE;
-					} 
-				}
 				if (!viewer->stop_previous && !claws_is_exiting())
-					html_document_write_stream(viewer->html_doc, buf, loaded);
-				else {
+				{
+					if (skip_header && strcasestr(buf, "</head>") != NULL)
+					{
+						gchar *substr;
+						insert_charset_header(viewer->html_doc, charset);
+						skip_header = FALSE;
+
+						substr = strcasestr(buf, "</head>")
+							+ strlen("</head>");
+						html_document_write_stream(viewer->html_doc,
+							substr, strlen(substr));
+
+    					} else if (!skip_header)
+						html_document_write_stream(viewer->html_doc,
+							buf, strlen(buf));
+				} else {
 					g_mutex_unlock(viewer->mutex);
 					break;
 				}
@@ -367,6 +330,7 @@ static gint gtkhtml2_show_mimepart_real(MimeViewer *_viewer)
 				if (gtk_events_pending())
 					gtk_main_iteration();
 			}
+
 			fclose(fp);
 			html_document_close_stream(viewer->html_doc);
 			viewer->mimeinfo = partinfo;
@@ -409,7 +373,7 @@ static gint gtkhtml2_show_mimepart_prepare(MimeViewer *_viewer)
 		g_mutex_unlock(viewer->mutex);
 		return TRUE;
 	}
-	viewer->tag = g_timeout_add(5, (GtkFunction)gtkhtml2_show_mimepart_real, viewer);
+	viewer->tag = g_timeout_add(5, (GSourceFunc)gtkhtml2_show_mimepart_real, viewer);
 	g_mutex_unlock(viewer->mutex);
 	return FALSE;
 }
