@@ -61,6 +61,10 @@ static void trayicon_toggle_notify_cb(GtkAction*,gpointer);
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
 
+#ifndef NOTIFY_CHECK_VERSION
+# define NOTIFY_CHECK_VERSION(a,b,c) 0
+#endif
+
 typedef struct {
   gint count;
   gint num_mail;
@@ -602,8 +606,12 @@ static gboolean notification_trayicon_popup_create(MsgInfo *msginfo,
   summary  = notification_trayicon_popup_assemble_summary();
   utf8_str = notification_trayicon_popup_assemble_body(msginfo);
 
+#if NOTIFY_CHECK_VERSION(0, 7, 0)
+  popup.notification = notify_notification_new(summary, utf8_str, NULL);
+#else
   popup.notification = notify_notification_new(summary, utf8_str, NULL, NULL);
   notify_notification_attach_to_status_icon(popup.notification, trayicon);
+#endif
 
   g_free(summary);
   g_free(utf8_str);
