@@ -470,7 +470,7 @@ static GtkActionEntry mainwindow_tools_python_actions[] = {
     {"Tools/PythonScripts", NULL, N_("Python scripts") },
     {"Tools/PythonScripts/Refresh", NULL, N_("Refresh"),
         NULL, NULL, G_CALLBACK(refresh_python_scripts_menus) },
-    {"Tools/PythonScripts/Browse", NULL, "Browse",
+    {"Tools/PythonScripts/Browse", NULL, N_("Browse"),
         NULL, NULL, G_CALLBACK(browse_python_scripts_dir) },
     {"Tools/PythonScripts/---", NULL, "---" },
 };
@@ -479,6 +479,12 @@ void python_menu_init(void)
 {
   MainWindow *mainwin;
   guint id;
+#ifdef ENABLE_NLS
+	char *tdomain = strdup(textdomain(NULL)); /* Store current translation domain. */
+
+	/* Set our gettext translation domain for menu items below. */
+	textdomain(TEXTDOMAIN);
+#endif
 
   mainwin =  mainwindow_get_mainwindow();
 
@@ -505,6 +511,12 @@ void python_menu_init(void)
       "Tools/PythonScripts/---", GTK_UI_MANAGER_SEPARATOR, id)
   menu_id_list = g_slist_prepend(menu_id_list, GUINT_TO_POINTER(id));
 
+#ifdef ENABLE_NLS
+	/* Restore previous translation domain, as to not break stuff. */
+	textdomain(tdomain);
+	g_free(tdomain);
+#endif
+
   refresh_python_scripts_menus(NULL, NULL);
 }
 
@@ -539,14 +551,14 @@ gint plugin_init(gchar **error)
   bind_textdomain_codeset(TEXTDOMAIN, "UTF-8");
 
   /* Version check */
-  if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,3,14),
+  if(!check_plugin_version(MAKE_NUMERIC_VERSION(3,7,6,9),
 			   VERSION_NUMERIC, _("Python"), error))
     return -1;
 
   /* load hooks */
   hook_compose_create = hooks_register_hook(COMPOSE_CREATED_HOOKLIST, my_compose_create_hook, NULL);
   if(hook_compose_create == (guint)-1) {
-    *error = g_strdup(_("Failed to register compose create hook int the Python plugin"));
+    *error = g_strdup(_("Failed to register \"compose create hook\" in the Python plugin"));
     return -1;
   }
 
@@ -600,6 +612,13 @@ const gchar *plugin_name(void)
 const gchar *plugin_desc(void)
 {
   return _("This plugin provides Python integration features.\n"
+           "\nFor the most up-to-date API documentation, type\n"
+           "\n help(clawsmail)\n"
+           "\nin the interactive Python console under Tools -> Show Python console.\n"
+           "\nThe source distribution of this plugin comes with various example scripts "
+           "in the \"examples\" subdirectory. If you wrote a script that you would be "
+           "interested in sharing, feel free to send it to me to have it considered "
+           "for inclusion in the examples.\n"
            "\nFeedback to <berndth@gmx.de> is welcome.");
 }
 
