@@ -327,6 +327,9 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 			0, 2, row, row+1,
 			(GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
 			(GtkAttachOptions) (0), 10, 0);
+	g_signal_connect(G_OBJECT(feedprop->fetch_comments), "toggled",
+			G_CALLBACK(rssyl_fetch_comments_toggled_cb),
+			(gpointer)feedprop->fetch_comments_for);
 	row++;
 
 	/* Fetch comments for - label */
@@ -340,6 +343,8 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 			(GtkAttachOptions) (0), 10, 5);
 
 	/* Fetch comments for - spinbutton */
+	gtk_widget_set_sensitive(feedprop->fetch_comments_for,
+			ritem->fetch_comments);
 	gtk_table_attach(GTK_TABLE(table), feedprop->fetch_comments_for, 1, 2, row, row+1,
 			(GtkAttachOptions) (0),
 			(GtkAttachOptions) (0), 10, 5);
@@ -477,7 +482,7 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 	/* OK button */
 	ok_button = gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(bbox), ok_button);
-	GTK_WIDGET_SET_FLAGS(ok_button, GTK_CAN_DEFAULT );
+	gtkut_widget_set_can_default(ok_button, TRUE);
 
 	ok_align = gtk_alignment_new(0.5, 0.5, 0, 0);
 	gtk_container_add(GTK_CONTAINER(ok_button), ok_align);
@@ -502,6 +507,10 @@ static RSSylFeedProp *rssyl_gtk_prop_real(RSSylFolderItem *ritem)
 	gtk_window_set_transient_for(GTK_WINDOW(feedprop->window),
 			GTK_WINDOW(mainwin->window) );
 
+	/* Attach callbacks to handle Enter and Escape keys */
+	g_signal_connect(G_OBJECT(feedprop->window), "key_press_event",
+			G_CALLBACK(rssyl_props_key_press_cb), ritem);
+
 	/* ...and voila! */
 	gtk_widget_show_all(feedprop->window);
 	gtk_widget_grab_default(ok_button);
@@ -620,7 +629,6 @@ GtkWidget *rssyl_feed_removal_dialog(gchar *name, GtkWidget **rmcache_widget)
 	dialog = gtk_dialog_new();
 	gtk_window_set_title(GTK_WINDOW(dialog), _("Unsubscribe feed"));
 	gtk_window_set_type_hint(GTK_WINDOW(dialog), GDK_WINDOW_TYPE_HINT_DIALOG);
-	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
 
 	vbox = GTK_DIALOG(dialog)->vbox;
 
@@ -661,8 +669,8 @@ GtkWidget *rssyl_feed_removal_dialog(gchar *name, GtkWidget **rmcache_widget)
 
 	bno = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
 	gtk_dialog_add_action_widget(GTK_DIALOG(dialog), bno, GTK_RESPONSE_NO);
-	GTK_WIDGET_SET_FLAGS(bno, GTK_CAN_DEFAULT);
-
+	gtkut_widget_set_can_default(bno, TRUE);
+	
 	byes = gtk_button_new_with_mnemonic(_("_Unsubscribe"));
 	gtk_dialog_add_action_widget(GTK_DIALOG(dialog), byes, GTK_RESPONSE_YES);
 
