@@ -1824,7 +1824,7 @@ gboolean vcal_meeting_send(VCalMeeting *meet)
 	return send_meeting_cb(NULL, meet);
 }
 
-gint vcal_meeting_alert_check(gpointer data)
+gboolean vcal_meeting_alert_check(gpointer data)
 {
 	GSList *events = NULL, *cur = NULL;
 
