@@ -1292,7 +1292,7 @@ MimeViewerFactory vcal_viewer_factory =
 static gint alert_timeout_tag = 0;
 static gint scan_timeout_tag = 0;
 
-static gint vcal_webcal_check(gpointer data)
+static gboolean vcal_webcal_check(gpointer data)
 {
 	Folder *root = folder_find_from_name ("vCalendar", vcal_folder_get_class());
 
@@ -1348,10 +1348,10 @@ void vcalendar_init(void)
 	vcal_folder_gtk_init();
 
 	alert_timeout_tag = g_timeout_add(60*1000, 
-				(GtkFunction)vcal_meeting_alert_check, 
+				(GSourceFunc)vcal_meeting_alert_check, 
 				(gpointer)NULL);
 	scan_timeout_tag = g_timeout_add(3600*1000, 
-				(GtkFunction)vcal_webcal_check, 
+				(GSourceFunc)vcal_webcal_check, 
 				(gpointer)NULL);
 	if (prefs_common_get_prefs()->enable_color) {
 		gtkut_convert_int_to_gdk_color(prefs_common_get_prefs()->uri_col,
